@@ -35,15 +35,15 @@ def parse_cmd(config, client):
     return args.URL
 
 def create_config(CONFIG_FILE):
-    config = {
-        'sp_dc': "", 
-        'download_path': "downloads", 
-        'create_folder': True, 
-        'album_folder_name': "{name} - {artists}", 
-        'play_folder_name': "{name} - {owner}", 
-        'file_name': "{track_number}. {name}",
-        'synced_lyrics': True, 
-        'force_synced': False
-     }
+    print("Editing Config File...")
+    config = {}
+    config['sp_dc'] = input("Enter the sp_dc (https://github.com/akashrchandran/syrics/wiki/Finding-sp_dc): \n") or ""
+    config['download_path'] = input("Enter the download path: \n") or "downloads"
+    config['create_folder'] = bool(int(input("create folder for album/playlists: (0: False, 1: True)")))
+    config['album_folder_name'] = input("Enter the album folder naming format: ") or "{name} - {artists}"
+    config['album_folder_name'] = input("Enter the playlist folder naming format: ") or "{name} - {owner}"
+    config['album_folder_name'] = input("Enter the file naming format: ") or "{track_number}. {name}"
+    config['synced_lyrics'] = bool(int(input("Get synced lyrics: (0: False, 1: True)")))
+    config['force_synced'] = bool(int(input("Only get synced lyrics: (0: False, 1: True)")))
     with open(CONFIG_FILE, "w+") as f:
         f.write(json.dumps(config, indent=4))
\ No newline at end of file
