@@ -14,18 +14,14 @@ from syrics.exceptions import CorruptedConfig
 platform = os.name == "nt"
 if platform:
     OS_CONFIG = os.environ.get("APPDATA")
-    EDIT_CMD = "notepad.exe"
 else:
     OS_CONFIG = os.path.join(os.environ["HOME"], ".config")
-    EDIT_CMD = "nano"
-
 
 CONFIG_PATH = os.path.join(OS_CONFIG, "syrics")
 CONFIG_FILE = os.path.join(CONFIG_PATH, "config.json")
 if not os.path.isdir(CONFIG_PATH) or not os.path.isfile(CONFIG_FILE):
         os.makedirs(CONFIG_PATH, exist_ok=True)
         create_config(CONFIG_FILE)
-        os.system(f"{EDIT_CMD} {CONFIG_FILE}")
 
 try:
     with open(CONFIG_FILE) as f:
@@ -80,7 +76,7 @@ def format_lrc(lyrics_json):
         for lines in lyrics:
             duration = int(lines['startTimeMs'])
             minutes, seconds = divmod(duration / 1000, 60)
-            lrc.append(f'[{minutes:0>2.0f}:{seconds:.3f}] {lines["words"]}')
+            lrc.append(f'[{minutes:0>2.0f}:{seconds:05.2f}] {lines["words"]}')
     return '\n'.join(lrc)
 
 
@@ -183,4 +179,4 @@ def main():
     if unable:
         print("\nsome tracks does not have lyrics, so skipped:")
         for tracks in unable:
-            print(tracks)
\ No newline at end of file
+            print(tracks)
